# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.monitoring_dashboard_v1.types import metrics

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Scorecard",
    },
)


class Scorecard(proto.Message):
    r"""A widget showing the latest value of a metric, and how this
    value relates to one or more thresholds.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        time_series_query (google.cloud.monitoring_dashboard_v1.types.TimeSeriesQuery):
            Required. Fields for querying time series
            data from the Stackdriver metrics API.
        gauge_view (google.cloud.monitoring_dashboard_v1.types.Scorecard.GaugeView):
            Will cause the scorecard to show a gauge
            chart.

            This field is a member of `oneof`_ ``data_view``.
        spark_chart_view (google.cloud.monitoring_dashboard_v1.types.Scorecard.SparkChartView):
            Will cause the scorecard to show a spark
            chart.

            This field is a member of `oneof`_ ``data_view``.
        blank_view (google.protobuf.empty_pb2.Empty):
            Will cause the ``Scorecard`` to show only the value, with no
            indicator to its value relative to its thresholds.

            This field is a member of `oneof`_ ``data_view``.
        thresholds (MutableSequence[google.cloud.monitoring_dashboard_v1.types.Threshold]):
            The thresholds used to determine the state of the scorecard
            given the time series' current value. For an actual value x,
            the scorecard is in a danger state if x is less than or
            equal to a danger threshold that triggers below, or greater
            than or equal to a danger threshold that triggers above.
            Similarly, if x is above/below a warning threshold that
            triggers above/below, then the scorecard is in a warning
            state - unless x also puts it in a danger state. (Danger
            trumps warning.)

            As an example, consider a scorecard with the following four
            thresholds:

            ::

               {
                 value: 90,
                 category: 'DANGER',
                 trigger: 'ABOVE',
               },
               {
                 value: 70,
                 category: 'WARNING',
                 trigger: 'ABOVE',
               },
               {
                 value: 10,
                 category: 'DANGER',
                 trigger: 'BELOW',
               },
               {
                 value: 20,
                 category: 'WARNING',
                 trigger: 'BELOW',
               }

            Then: values less than or equal to 10 would put the
            scorecard in a DANGER state, values greater than 10 but less
            than or equal to 20 a WARNING state, values strictly between
            20 and 70 an OK state, values greater than or equal to 70
            but less than 90 a WARNING state, and values greater than or
            equal to 90 a DANGER state.
    """

    class GaugeView(proto.Message):
        r"""A gauge chart shows where the current value sits within a
        pre-defined range. The upper and lower bounds should define the
        possible range of values for the scorecard's query (inclusive).

        Attributes:
            lower_bound (float):
                The lower bound for this gauge chart. The
                value of the chart should always be greater than
                or equal to this.
            upper_bound (float):
                The upper bound for this gauge chart. The
                value of the chart should always be less than or
                equal to this.
        """

        lower_bound: float = proto.Field(
            proto.DOUBLE,
            number=1,
        )
        upper_bound: float = proto.Field(
            proto.DOUBLE,
            number=2,
        )

    class SparkChartView(proto.Message):
        r"""A sparkChart is a small chart suitable for inclusion in a
        table-cell or inline in text. This message contains the
        configuration for a sparkChart to show up on a Scorecard,
        showing recent trends of the scorecard's timeseries.

        Attributes:
            spark_chart_type (google.cloud.monitoring_dashboard_v1.types.SparkChartType):
                Required. The type of sparkchart to show in
                this chartView.
            min_alignment_period (google.protobuf.duration_pb2.Duration):
                The lower bound on data point frequency in
                the chart implemented by specifying the minimum
                alignment period to use in a time series query.
                For example, if the data is published once every
                10 minutes it would not make sense to fetch and
                align data at one minute intervals. This field
                is optional and exists only as a hint.
        """

        spark_chart_type: metrics.SparkChartType = proto.Field(
            proto.ENUM,
            number=1,
            enum=metrics.SparkChartType,
        )
        min_alignment_period: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=2,
            message=duration_pb2.Duration,
        )

    time_series_query: metrics.TimeSeriesQuery = proto.Field(
        proto.MESSAGE,
        number=1,
        message=metrics.TimeSeriesQuery,
    )
    gauge_view: GaugeView = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="data_view",
        message=GaugeView,
    )
    spark_chart_view: SparkChartView = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="data_view",
        message=SparkChartView,
    )
    blank_view: empty_pb2.Empty = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="data_view",
        message=empty_pb2.Empty,
    )
    thresholds: MutableSequence[metrics.Threshold] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=metrics.Threshold,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.type import interval_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Aggregation",
        "PickTimeSeriesFilter",
        "StatisticalTimeSeriesFilter",
    },
)


class Aggregation(proto.Message):
    r"""Describes how to combine multiple time series to provide a different
    view of the data. Aggregation of time series is done in two steps.
    First, each time series in the set is *aligned* to the same time
    interval boundaries, then the set of time series is optionally
    *reduced* in number.

    Alignment consists of applying the ``per_series_aligner`` operation
    to each time series after its data has been divided into regular
    ``alignment_period`` time intervals. This process takes *all* of the
    data points in an alignment period, applies a mathematical
    transformation such as averaging, minimum, maximum, delta, etc., and
    converts them into a single data point per period.

    Reduction is when the aligned and transformed time series can
    optionally be combined, reducing the number of time series through
    similar mathematical transformations. Reduction involves applying a
    ``cross_series_reducer`` to all the time series, optionally sorting
    the time series into subsets with ``group_by_fields``, and applying
    the reducer to each subset.

    The raw time series data can contain a huge amount of information
    from multiple sources. Alignment and reduction transforms this mass
    of data into a more manageable and representative collection of
    data, for example "the 95% latency across the average of all tasks
    in a cluster". This representative data can be more easily graphed
    and comprehended, and the individual time series data is still
    available for later drilldown. For more details, see `Filtering and
    aggregation <https://cloud.google.com/monitoring/api/v3/aggregation>`__.

    Attributes:
        alignment_period (google.protobuf.duration_pb2.Duration):
            The ``alignment_period`` specifies a time interval, in
            seconds, that is used to divide the data in all the [time
            series][google.monitoring.v3.TimeSeries] into consistent
            blocks of time. This will be done before the per-series
            aligner can be applied to the data.

            The value must be at least 60 seconds. If a per-series
            aligner other than ``ALIGN_NONE`` is specified, this field
            is required or an error is returned. If no per-series
            aligner is specified, or the aligner ``ALIGN_NONE`` is
            specified, then this field is ignored.

            The maximum value of the ``alignment_period`` is 2 years, or
            104 weeks.
        per_series_aligner (google.cloud.monitoring_dashboard_v1.types.Aggregation.Aligner):
            An ``Aligner`` describes how to bring the data points in a
            single time series into temporal alignment. Except for
            ``ALIGN_NONE``, all alignments cause all the data points in
            an ``alignment_period`` to be mathematically grouped
            together, resulting in a single data point for each
            ``alignment_period`` with end timestamp at the end of the
            period.

            Not all alignment operations may be applied to all time
            series. The valid choices depend on the ``metric_kind`` and
            ``value_type`` of the original time series. Alignment can
            change the ``metric_kind`` or the ``value_type`` of the time
            series.

            Time series data must be aligned in order to perform
            cross-time series reduction. If ``cross_series_reducer`` is
            specified, then ``per_series_aligner`` must be specified and
            not equal to ``ALIGN_NONE`` and ``alignment_period`` must be
            specified; otherwise, an error is returned.
        cross_series_reducer (google.cloud.monitoring_dashboard_v1.types.Aggregation.Reducer):
            The reduction operation to be used to combine time series
            into a single time series, where the value of each data
            point in the resulting series is a function of all the
            already aligned values in the input time series.

            Not all reducer operations can be applied to all time
            series. The valid choices depend on the ``metric_kind`` and
            the ``value_type`` of the original time series. Reduction
            can yield a time series with a different ``metric_kind`` or
            ``value_type`` than the input time series.

            Time series data must first be aligned (see
            ``per_series_aligner``) in order to perform cross-time
            series reduction. If ``cross_series_reducer`` is specified,
            then ``per_series_aligner`` must be specified, and must not
            be ``ALIGN_NONE``. An ``alignment_period`` must also be
            specified; otherwise, an error is returned.
        group_by_fields (MutableSequence[str]):
            The set of fields to preserve when ``cross_series_reducer``
            is specified. The ``group_by_fields`` determine how the time
            series are partitioned into subsets prior to applying the
            aggregation operation. Each subset contains time series that
            have the same value for each of the grouping fields. Each
            individual time series is a member of exactly one subset.
            The ``cross_series_reducer`` is applied to each subset of
            time series. It is not possible to reduce across different
            resource types, so this field implicitly contains
            ``resource.type``. Fields not specified in
            ``group_by_fields`` are aggregated away. If
            ``group_by_fields`` is not specified and all the time series
            have the same resource type, then the time series are
            aggregated into a single output time series. If
            ``cross_series_reducer`` is not defined, this field is
            ignored.
    """

    class Aligner(proto.Enum):
        r"""The ``Aligner`` specifies the operation that will be applied to the
        data points in each alignment period in a time series. Except for
        ``ALIGN_NONE``, which specifies that no operation be applied, each
        alignment operation replaces the set of data values in each
        alignment period with a single value: the result of applying the
        operation to the data values. An aligned time series has a single
        data value at the end of each ``alignment_period``.

        An alignment operation can change the data type of the values, too.
        For example, if you apply a counting operation to boolean values,
        the data ``value_type`` in the original time series is ``BOOLEAN``,
        but the ``value_type`` in the aligned result is ``INT64``.

        Values:
            ALIGN_NONE (0):
                No alignment. Raw data is returned. Not valid if
                cross-series reduction is requested. The ``value_type`` of
                the result is the same as the ``value_type`` of the input.
            ALIGN_DELTA (1):
                Align and convert to
                [DELTA][google.api.MetricDescriptor.MetricKind.DELTA]. The
                output is ``delta = y1 - y0``.

                This alignment is valid for
                [CUMULATIVE][google.api.MetricDescriptor.MetricKind.CUMULATIVE]
                and ``DELTA`` metrics. If the selected alignment period
                results in periods with no data, then the aligned value for
                such a period is created by interpolation. The
                ``value_type`` of the aligned result is the same as the
                ``value_type`` of the input.
            ALIGN_RATE (2):
                Align and convert to a rate. The result is computed as
                ``rate = (y1 - y0)/(t1 - t0)``, or "delta over time". Think
                of this aligner as providing the slope of the line that
                passes through the value at the start and at the end of the
                ``alignment_period``.

                This aligner is valid for ``CUMULATIVE`` and ``DELTA``
                metrics with numeric values. If the selected alignment
                period results in periods with no data, then the aligned
                value for such a period is created by interpolation. The
                output is a ``GAUGE`` metric with ``value_type`` ``DOUBLE``.

                If, by "rate", you mean "percentage change", see the
                ``ALIGN_PERCENT_CHANGE`` aligner instead.
            ALIGN_INTERPOLATE (3):
                Align by interpolating between adjacent points around the
                alignment period boundary. This aligner is valid for
                ``GAUGE`` metrics with numeric values. The ``value_type`` of
                the aligned result is the same as the ``value_type`` of the
                input.
            ALIGN_NEXT_OLDER (4):
                Align by moving the most recent data point before the end of
                the alignment period to the boundary at the end of the
                alignment period. This aligner is valid for ``GAUGE``
                metrics. The ``value_type`` of the aligned result is the
                same as the ``value_type`` of the input.
            ALIGN_MIN (10):
                Align the time series by returning the minimum value in each
                alignment period. This aligner is valid for ``GAUGE`` and
                ``DELTA`` metrics with numeric values. The ``value_type`` of
                the aligned result is the same as the ``value_type`` of the
                input.
            ALIGN_MAX (11):
                Align the time series by returning the maximum value in each
                alignment period. This aligner is valid for ``GAUGE`` and
                ``DELTA`` metrics with numeric values. The ``value_type`` of
                the aligned result is the same as the ``value_type`` of the
                input.
            ALIGN_MEAN (12):
                Align the time series by returning the mean value in each
                alignment period. This aligner is valid for ``GAUGE`` and
                ``DELTA`` metrics with numeric values. The ``value_type`` of
                the aligned result is ``DOUBLE``.
            ALIGN_COUNT (13):
                Align the time series by returning the number of values in
                each alignment period. This aligner is valid for ``GAUGE``
                and ``DELTA`` metrics with numeric or Boolean values. The
                ``value_type`` of the aligned result is ``INT64``.
            ALIGN_SUM (14):
                Align the time series by returning the sum of the values in
                each alignment period. This aligner is valid for ``GAUGE``
                and ``DELTA`` metrics with numeric and distribution values.
                The ``value_type`` of the aligned result is the same as the
                ``value_type`` of the input.
            ALIGN_STDDEV (15):
                Align the time series by returning the standard deviation of
                the values in each alignment period. This aligner is valid
                for ``GAUGE`` and ``DELTA`` metrics with numeric values. The
                ``value_type`` of the output is ``DOUBLE``.
            ALIGN_COUNT_TRUE (16):
                Align the time series by returning the number of ``True``
                values in each alignment period. This aligner is valid for
                ``GAUGE`` metrics with Boolean values. The ``value_type`` of
                the output is ``INT64``.
            ALIGN_COUNT_FALSE (24):
                Align the time series by returning the number of ``False``
                values in each alignment period. This aligner is valid for
                ``GAUGE`` metrics with Boolean values. The ``value_type`` of
                the output is ``INT64``.
            ALIGN_FRACTION_TRUE (17):
                Align the time series by returning the ratio of the number
                of ``True`` values to the total number of values in each
                alignment period. This aligner is valid for ``GAUGE``
                metrics with Boolean values. The output value is in the
                range [0.0, 1.0] and has ``value_type`` ``DOUBLE``.
            ALIGN_PERCENTILE_99 (18):
                Align the time series by using `percentile
                aggregation <https://en.wikipedia.org/wiki/Percentile>`__.
                The resulting data point in each alignment period is the
                99th percentile of all data points in the period. This
                aligner is valid for ``GAUGE`` and ``DELTA`` metrics with
                distribution values. The output is a ``GAUGE`` metric with
                ``value_type`` ``DOUBLE``.
            ALIGN_PERCENTILE_95 (19):
                Align the time series by using `percentile
                aggregation <https://en.wikipedia.org/wiki/Percentile>`__.
                The resulting data point in each alignment period is the
                95th percentile of all data points in the period. This
                aligner is valid for ``GAUGE`` and ``DELTA`` metrics with
                distribution values. The output is a ``GAUGE`` metric with
                ``value_type`` ``DOUBLE``.
            ALIGN_PERCENTILE_50 (20):
                Align the time series by using `percentile
                aggregation <https://en.wikipedia.org/wiki/Percentile>`__.
                The resulting data point in each alignment period is the
                50th percentile of all data points in the period. This
                aligner is valid for ``GAUGE`` and ``DELTA`` metrics with
                distribution values. The output is a ``GAUGE`` metric with
                ``value_type`` ``DOUBLE``.
            ALIGN_PERCENTILE_05 (21):
                Align the time series by using `percentile
                aggregation <https://en.wikipedia.org/wiki/Percentile>`__.
                The resulting data point in each alignment period is the 5th
                percentile of all data points in the period. This aligner is
                valid for ``GAUGE`` and ``DELTA`` metrics with distribution
                values. The output is a ``GAUGE`` metric with ``value_type``
                ``DOUBLE``.
            ALIGN_PERCENT_CHANGE (23):
                Align and convert to a percentage change. This aligner is
                valid for ``GAUGE`` and ``DELTA`` metrics with numeric
                values. This alignment returns
                ``((current - previous)/previous) * 100``, where the value
                of ``previous`` is determined based on the
                ``alignment_period``.

                If the values of ``current`` and ``previous`` are both 0,
                then the returned value is 0. If only ``previous`` is 0, the
                returned value is infinity.

                A 10-minute moving mean is computed at each point of the
                alignment period prior to the above calculation to smooth
                the metric and prevent false positives from very short-lived
                spikes. The moving mean is only applicable for data whose
                values are ``>= 0``. Any values ``< 0`` are treated as a
                missing datapoint, and are ignored. While ``DELTA`` metrics
                are accepted by this alignment, special care should be taken
                that the values for the metric will always be positive. The
                output is a ``GAUGE`` metric with ``value_type`` ``DOUBLE``.
        """
        ALIGN_NONE = 0
        ALIGN_DELTA = 1
        ALIGN_RATE = 2
        ALIGN_INTERPOLATE = 3
        ALIGN_NEXT_OLDER = 4
        ALIGN_MIN = 10
        ALIGN_MAX = 11
        ALIGN_MEAN = 12
        ALIGN_COUNT = 13
        ALIGN_SUM = 14
        ALIGN_STDDEV = 15
        ALIGN_COUNT_TRUE = 16
        ALIGN_COUNT_FALSE = 24
        ALIGN_FRACTION_TRUE = 17
        ALIGN_PERCENTILE_99 = 18
        ALIGN_PERCENTILE_95 = 19
        ALIGN_PERCENTILE_50 = 20
        ALIGN_PERCENTILE_05 = 21
        ALIGN_PERCENT_CHANGE = 23

    class Reducer(proto.Enum):
        r"""A Reducer operation describes how to aggregate data points
        from multiple time series into a single time series, where the
        value of each data point in the resulting series is a function
        of all the already aligned values in the input time series.

        Values:
            REDUCE_NONE (0):
                No cross-time series reduction. The output of the
                ``Aligner`` is returned.
            REDUCE_MEAN (1):
                Reduce by computing the mean value across time series for
                each alignment period. This reducer is valid for
                [DELTA][google.api.MetricDescriptor.MetricKind.DELTA] and
                [GAUGE][google.api.MetricDescriptor.MetricKind.GAUGE]
                metrics with numeric or distribution values. The
                ``value_type`` of the output is
                [DOUBLE][google.api.MetricDescriptor.ValueType.DOUBLE].
            REDUCE_MIN (2):
                Reduce by computing the minimum value across time series for
                each alignment period. This reducer is valid for ``DELTA``
                and ``GAUGE`` metrics with numeric values. The
                ``value_type`` of the output is the same as the
                ``value_type`` of the input.
            REDUCE_MAX (3):
                Reduce by computing the maximum value across time series for
                each alignment period. This reducer is valid for ``DELTA``
                and ``GAUGE`` metrics with numeric values. The
                ``value_type`` of the output is the same as the
                ``value_type`` of the input.
            REDUCE_SUM (4):
                Reduce by computing the sum across time series for each
                alignment period. This reducer is valid for ``DELTA`` and
                ``GAUGE`` metrics with numeric and distribution values. The
                ``value_type`` of the output is the same as the
                ``value_type`` of the input.
            REDUCE_STDDEV (5):
                Reduce by computing the standard deviation across time
                series for each alignment period. This reducer is valid for
                ``DELTA`` and ``GAUGE`` metrics with numeric or distribution
                values. The ``value_type`` of the output is ``DOUBLE``.
            REDUCE_COUNT (6):
                Reduce by computing the number of data points across time
                series for each alignment period. This reducer is valid for
                ``DELTA`` and ``GAUGE`` metrics of numeric, Boolean,
                distribution, and string ``value_type``. The ``value_type``
                of the output is ``INT64``.
            REDUCE_COUNT_TRUE (7):
                Reduce by computing the number of ``True``-valued data
                points across time series for each alignment period. This
                reducer is valid for ``DELTA`` and ``GAUGE`` metrics of
                Boolean ``value_type``. The ``value_type`` of the output is
                ``INT64``.
            REDUCE_COUNT_FALSE (15):
                Reduce by computing the number of ``False``-valued data
                points across time series for each alignment period. This
                reducer is valid for ``DELTA`` and ``GAUGE`` metrics of
                Boolean ``value_type``. The ``value_type`` of the output is
                ``INT64``.
            REDUCE_FRACTION_TRUE (8):
                Reduce by computing the ratio of the number of
                ``True``-valued data points to the total number of data
                points for each alignment period. This reducer is valid for
                ``DELTA`` and ``GAUGE`` metrics of Boolean ``value_type``.
                The output value is in the range [0.0, 1.0] and has
                ``value_type`` ``DOUBLE``.
            REDUCE_PERCENTILE_99 (9):
                Reduce by computing the `99th
                percentile <https://en.wikipedia.org/wiki/Percentile>`__ of
                data points across time series for each alignment period.
                This reducer is valid for ``GAUGE`` and ``DELTA`` metrics of
                numeric and distribution type. The value of the output is
                ``DOUBLE``.
            REDUCE_PERCENTILE_95 (10):
                Reduce by computing the `95th
                percentile <https://en.wikipedia.org/wiki/Percentile>`__ of
                data points across time series for each alignment period.
                This reducer is valid for ``GAUGE`` and ``DELTA`` metrics of
                numeric and distribution type. The value of the output is
                ``DOUBLE``.
            REDUCE_PERCENTILE_50 (11):
                Reduce by computing the `50th
                percentile <https://en.wikipedia.org/wiki/Percentile>`__ of
                data points across time series for each alignment period.
                This reducer is valid for ``GAUGE`` and ``DELTA`` metrics of
                numeric and distribution type. The value of the output is
                ``DOUBLE``.
            REDUCE_PERCENTILE_05 (12):
                Reduce by computing the `5th
                percentile <https://en.wikipedia.org/wiki/Percentile>`__ of
                data points across time series for each alignment period.
                This reducer is valid for ``GAUGE`` and ``DELTA`` metrics of
                numeric and distribution type. The value of the output is
                ``DOUBLE``.
        """
        REDUCE_NONE = 0
        REDUCE_MEAN = 1
        REDUCE_MIN = 2
        REDUCE_MAX = 3
        REDUCE_SUM = 4
        REDUCE_STDDEV = 5
        REDUCE_COUNT = 6
        REDUCE_COUNT_TRUE = 7
        REDUCE_COUNT_FALSE = 15
        REDUCE_FRACTION_TRUE = 8
        REDUCE_PERCENTILE_99 = 9
        REDUCE_PERCENTILE_95 = 10
        REDUCE_PERCENTILE_50 = 11
        REDUCE_PERCENTILE_05 = 12

    alignment_period: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )
    per_series_aligner: Aligner = proto.Field(
        proto.ENUM,
        number=2,
        enum=Aligner,
    )
    cross_series_reducer: Reducer = proto.Field(
        proto.ENUM,
        number=4,
        enum=Reducer,
    )
    group_by_fields: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


class PickTimeSeriesFilter(proto.Message):
    r"""Describes a ranking-based time series filter. Each input time series
    is ranked with an aligner. The filter will allow up to
    ``num_time_series`` time series to pass through it, selecting them
    based on the relative ranking.

    For example, if ``ranking_method`` is
    ``METHOD_MEAN``,\ ``direction`` is ``BOTTOM``, and
    ``num_time_series`` is 3, then the 3 times series with the lowest
    mean values will pass through the filter.

    Attributes:
        ranking_method (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter.Method):
            ``ranking_method`` is applied to each time series
            independently to produce the value which will be used to
            compare the time series to other time series.
        num_time_series (int):
            How many time series to allow to pass through
            the filter.
        direction (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter.Direction):
            How to use the ranking to select time series
            that pass through the filter.
        interval (google.type.interval_pb2.Interval):
            Select the top N streams/time series within
            this time interval
    """

    class Method(proto.Enum):
        r"""The value reducers that can be applied to a
        ``PickTimeSeriesFilter``.

        Values:
            METHOD_UNSPECIFIED (0):
                Not allowed. You must specify a different ``Method`` if you
                specify a ``PickTimeSeriesFilter``.
            METHOD_MEAN (1):
                Select the mean of all values.
            METHOD_MAX (2):
                Select the maximum value.
            METHOD_MIN (3):
                Select the minimum value.
            METHOD_SUM (4):
                Compute the sum of all values.
            METHOD_LATEST (5):
                Select the most recent value.
        """
        METHOD_UNSPECIFIED = 0
        METHOD_MEAN = 1
        METHOD_MAX = 2
        METHOD_MIN = 3
        METHOD_SUM = 4
        METHOD_LATEST = 5

    class Direction(proto.Enum):
        r"""Describes the ranking directions.

        Values:
            DIRECTION_UNSPECIFIED (0):
                Not allowed. You must specify a different ``Direction`` if
                you specify a ``PickTimeSeriesFilter``.
            TOP (1):
                Pass the highest ``num_time_series`` ranking inputs.
            BOTTOM (2):
                Pass the lowest ``num_time_series`` ranking inputs.
        """
        DIRECTION_UNSPECIFIED = 0
        TOP = 1
        BOTTOM = 2

    ranking_method: Method = proto.Field(
        proto.ENUM,
        number=1,
        enum=Method,
    )
    num_time_series: int = proto.Field(
        proto.INT32,
        number=2,
    )
    direction: Direction = proto.Field(
        proto.ENUM,
        number=3,
        enum=Direction,
    )
    interval: interval_pb2.Interval = proto.Field(
        proto.MESSAGE,
        number=4,
        message=interval_pb2.Interval,
    )


class StatisticalTimeSeriesFilter(proto.Message):
    r"""A filter that ranks streams based on their statistical
    relation to other streams in a request.
    Note: This field is deprecated and completely ignored by the
    API.

    Attributes:
        ranking_method (google.cloud.monitoring_dashboard_v1.types.StatisticalTimeSeriesFilter.Method):
            ``rankingMethod`` is applied to a set of time series, and
            then the produced value for each individual time series is
            used to compare a given time series to others. These are
            methods that cannot be applied stream-by-stream, but rather
            require the full context of a request to evaluate time
            series.
        num_time_series (int):
            How many time series to output.
    """

    class Method(proto.Enum):
        r"""The filter methods that can be applied to a stream.

        Values:
            METHOD_UNSPECIFIED (0):
                Not allowed in well-formed requests.
            METHOD_CLUSTER_OUTLIER (1):
                Compute the outlier score of each stream.
        """
        METHOD_UNSPECIFIED = 0
        METHOD_CLUSTER_OUTLIER = 1

    ranking_method: Method = proto.Field(
        proto.ENUM,
        number=1,
        enum=Method,
    )
    num_time_series: int = proto.Field(
        proto.INT32,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Text",
    },
)


class Text(proto.Message):
    r"""A widget that displays textual content.

    Attributes:
        content (str):
            The text content to be displayed.
        format (~.text.Text.Format):
            How the text content is formatted.
    """

    class Format(proto.Enum):
        r"""The format type of the text content."""
        FORMAT_UNSPECIFIED = 0
        MARKDOWN = 1
        RAW = 2

    content = proto.Field(proto.STRING, number=1)

    format = proto.Field(
        proto.ENUM,
        number=2,
        enum=Format,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.monitoring_dashboard_v1.types import metrics

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "PieChart",
    },
)


class PieChart(proto.Message):
    r"""A widget that displays timeseries data as a pie or a donut.

    Attributes:
        data_sets (MutableSequence[google.cloud.monitoring_dashboard_v1.types.PieChart.PieChartDataSet]):
            Required. The queries for the chart's data.
        chart_type (google.cloud.monitoring_dashboard_v1.types.PieChart.PieChartType):
            Required. Indicates the visualization type
            for the PieChart.
        show_labels (bool):
            Optional. Indicates whether or not the pie
            chart should show slices' labels
    """

    class PieChartType(proto.Enum):
        r"""Types for the pie chart.

        Values:
            PIE_CHART_TYPE_UNSPECIFIED (0):
                The zero value. No type specified. Do not
                use.
            PIE (1):
                A Pie type PieChart.
            DONUT (2):
                Similar to PIE, but the DONUT type PieChart
                has a hole in the middle.
        """
        PIE_CHART_TYPE_UNSPECIFIED = 0
        PIE = 1
        DONUT = 2

    class PieChartDataSet(proto.Message):
        r"""Groups a time series query definition.

        Attributes:
            time_series_query (google.cloud.monitoring_dashboard_v1.types.TimeSeriesQuery):
                Required. The query for the PieChart. See,
                ``google.monitoring.dashboard.v1.TimeSeriesQuery``.
            slice_name_template (str):
                Optional. A template for the name of the slice. This name
                will be displayed in the legend and the tooltip of the pie
                chart. It replaces the auto-generated names for the slices.
                For example, if the template is set to
                ``${resource.labels.zone}``, the zone's value will be used
                for the name instead of the default name.
            min_alignment_period (google.protobuf.duration_pb2.Duration):
                Optional. The lower bound on data point frequency for this
                data set, implemented by specifying the minimum alignment
                period to use in a time series query. For example, if the
                data is published once every 10 minutes, the
                ``min_alignment_period`` should be at least 10 minutes. It
                would not make sense to fetch and align data at one minute
                intervals.
        """

        time_series_query: metrics.TimeSeriesQuery = proto.Field(
            proto.MESSAGE,
            number=1,
            message=metrics.TimeSeriesQuery,
        )
        slice_name_template: str = proto.Field(
            proto.STRING,
            number=2,
        )
        min_alignment_period: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=3,
            message=duration_pb2.Duration,
        )

    data_sets: MutableSequence[PieChartDataSet] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=PieChartDataSet,
    )
    chart_type: PieChartType = proto.Field(
        proto.ENUM,
        number=2,
        enum=PieChartType,
    )
    show_labels: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Text",
    },
)


class Text(proto.Message):
    r"""A widget that displays textual content.

    Attributes:
        content (str):
            The text content to be displayed.
        format_ (google.cloud.monitoring_dashboard_v1.types.Text.Format):
            How the text content is formatted.
        style (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle):
            How the text is styled
    """

    class Format(proto.Enum):
        r"""The format type of the text content.

        Values:
            FORMAT_UNSPECIFIED (0):
                Format is unspecified. Defaults to MARKDOWN.
            MARKDOWN (1):
                The text contains Markdown formatting.
            RAW (2):
                The text contains no special formatting.
        """
        FORMAT_UNSPECIFIED = 0
        MARKDOWN = 1
        RAW = 2

    class TextStyle(proto.Message):
        r"""Properties that determine how the title and content are
        styled

        Attributes:
            background_color (str):
                The background color as a hex string.
                "#RRGGBB" or "#RGB".
            text_color (str):
                The text color as a hex string. "#RRGGBB" or
                "#RGB".
            horizontal_alignment (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle.HorizontalAlignment):
                The horizontal alignment of both the title
                and content
            vertical_alignment (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle.VerticalAlignment):
                The vertical alignment of both the title and
                content
            padding (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle.PaddingSize):
                The amount of padding around the widget
            font_size (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle.FontSize):
                Font sizes for both the title and content.
                The title will still be larger relative to the
                content.
            pointer_location (google.cloud.monitoring_dashboard_v1.types.Text.TextStyle.PointerLocation):
                The pointer location for this widget (also
                sometimes called a "tail")
        """

        class HorizontalAlignment(proto.Enum):
            r"""The horizontal alignment of both the title and content on a
            text widget

            Values:
                HORIZONTAL_ALIGNMENT_UNSPECIFIED (0):
                    No horizontal alignment specified, will default to H_LEFT
                H_LEFT (1):
                    Left-align
                H_CENTER (2):
                    Center-align
                H_RIGHT (3):
                    Right-align
            """
            HORIZONTAL_ALIGNMENT_UNSPECIFIED = 0
            H_LEFT = 1
            H_CENTER = 2
            H_RIGHT = 3

        class VerticalAlignment(proto.Enum):
            r"""The vertical alignment of both the title and content on a
            text widget

            Values:
                VERTICAL_ALIGNMENT_UNSPECIFIED (0):
                    No vertical alignment specified, will default to V_TOP
                V_TOP (1):
                    Top-align
                V_CENTER (2):
                    Center-align
                V_BOTTOM (3):
                    Bottom-align
            """
            VERTICAL_ALIGNMENT_UNSPECIFIED = 0
            V_TOP = 1
            V_CENTER = 2
            V_BOTTOM = 3

        class PaddingSize(proto.Enum):
            r"""Specifies padding size around a text widget

            Values:
                PADDING_SIZE_UNSPECIFIED (0):
                    No padding size specified, will default to P_EXTRA_SMALL
                P_EXTRA_SMALL (1):
                    Extra small padding
                P_SMALL (2):
                    Small padding
                P_MEDIUM (3):
                    Medium padding
                P_LARGE (4):
                    Large padding
                P_EXTRA_LARGE (5):
                    Extra large padding
            """
            PADDING_SIZE_UNSPECIFIED = 0
            P_EXTRA_SMALL = 1
            P_SMALL = 2
            P_MEDIUM = 3
            P_LARGE = 4
            P_EXTRA_LARGE = 5

        class FontSize(proto.Enum):
            r"""Specifies a font size for the title and content of a text
            widget

            Values:
                FONT_SIZE_UNSPECIFIED (0):
                    No font size specified, will default to FS_LARGE
                FS_EXTRA_SMALL (1):
                    Extra small font size
                FS_SMALL (2):
                    Small font size
                FS_MEDIUM (3):
                    Medium font size
                FS_LARGE (4):
                    Large font size
                FS_EXTRA_LARGE (5):
                    Extra large font size
            """
            FONT_SIZE_UNSPECIFIED = 0
            FS_EXTRA_SMALL = 1
            FS_SMALL = 2
            FS_MEDIUM = 3
            FS_LARGE = 4
            FS_EXTRA_LARGE = 5

        class PointerLocation(proto.Enum):
            r"""Specifies where a visual pointer is placed on a text widget
            (also sometimes called a "tail")

            Values:
                POINTER_LOCATION_UNSPECIFIED (0):
                    No visual pointer
                PL_TOP (1):
                    Placed in the middle of the top of the widget
                PL_RIGHT (2):
                    Placed in the middle of the right side of the
                    widget
                PL_BOTTOM (3):
                    Placed in the middle of the bottom of the
                    widget
                PL_LEFT (4):
                    Placed in the middle of the left side of the
                    widget
                PL_TOP_LEFT (5):
                    Placed on the left side of the top of the
                    widget
                PL_TOP_RIGHT (6):
                    Placed on the right side of the top of the
                    widget
                PL_RIGHT_TOP (7):
                    Placed on the top of the right side of the
                    widget
                PL_RIGHT_BOTTOM (8):
                    Placed on the bottom of the right side of the
                    widget
                PL_BOTTOM_RIGHT (9):
                    Placed on the right side of the bottom of the
                    widget
                PL_BOTTOM_LEFT (10):
                    Placed on the left side of the bottom of the
                    widget
                PL_LEFT_BOTTOM (11):
                    Placed on the bottom of the left side of the
                    widget
                PL_LEFT_TOP (12):
                    Placed on the top of the left side of the
                    widget
            """
            POINTER_LOCATION_UNSPECIFIED = 0
            PL_TOP = 1
            PL_RIGHT = 2
            PL_BOTTOM = 3
            PL_LEFT = 4
            PL_TOP_LEFT = 5
            PL_TOP_RIGHT = 6
            PL_RIGHT_TOP = 7
            PL_RIGHT_BOTTOM = 8
            PL_BOTTOM_RIGHT = 9
            PL_BOTTOM_LEFT = 10
            PL_LEFT_BOTTOM = 11
            PL_LEFT_TOP = 12

        background_color: str = proto.Field(
            proto.STRING,
            number=1,
        )
        text_color: str = proto.Field(
            proto.STRING,
            number=2,
        )
        horizontal_alignment: "Text.TextStyle.HorizontalAlignment" = proto.Field(
            proto.ENUM,
            number=3,
            enum="Text.TextStyle.HorizontalAlignment",
        )
        vertical_alignment: "Text.TextStyle.VerticalAlignment" = proto.Field(
            proto.ENUM,
            number=4,
            enum="Text.TextStyle.VerticalAlignment",
        )
        padding: "Text.TextStyle.PaddingSize" = proto.Field(
            proto.ENUM,
            number=5,
            enum="Text.TextStyle.PaddingSize",
        )
        font_size: "Text.TextStyle.FontSize" = proto.Field(
            proto.ENUM,
            number=6,
            enum="Text.TextStyle.FontSize",
        )
        pointer_location: "Text.TextStyle.PointerLocation" = proto.Field(
            proto.ENUM,
            number=7,
            enum="Text.TextStyle.PointerLocation",
        )

    content: str = proto.Field(
        proto.STRING,
        number=1,
    )
    format_: Format = proto.Field(
        proto.ENUM,
        number=2,
        enum=Format,
    )
    style: TextStyle = proto.Field(
        proto.MESSAGE,
        number=3,
        message=TextStyle,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .alertchart import AlertChart
from .collapsible_group import CollapsibleGroup
from .common import Aggregation, PickTimeSeriesFilter, StatisticalTimeSeriesFilter
from .dashboard import Dashboard
from .dashboard_filter import DashboardFilter
from .dashboards_service import (
    CreateDashboardRequest,
    DeleteDashboardRequest,
    GetDashboardRequest,
    ListDashboardsRequest,
    ListDashboardsResponse,
    UpdateDashboardRequest,
)
from .error_reporting_panel import ErrorReportingPanel
from .incident_list import IncidentList
from .layouts import ColumnLayout, GridLayout, MosaicLayout, RowLayout
from .logs_panel import LogsPanel
from .metrics import (
    SparkChartType,
    Threshold,
    TimeSeriesFilter,
    TimeSeriesFilterRatio,
    TimeSeriesQuery,
)
from .piechart import PieChart
from .scorecard import Scorecard
from .section_header import SectionHeader
from .single_view_group import SingleViewGroup
from .table import TimeSeriesTable
from .table_display_options import TableDisplayOptions
from .text import Text
from .widget import Widget
from .xychart import ChartOptions, XyChart

__all__ = (
    "AlertChart",
    "CollapsibleGroup",
    "Aggregation",
    "PickTimeSeriesFilter",
    "StatisticalTimeSeriesFilter",
    "Dashboard",
    "DashboardFilter",
    "CreateDashboardRequest",
    "DeleteDashboardRequest",
    "GetDashboardRequest",
    "ListDashboardsRequest",
    "ListDashboardsResponse",
    "UpdateDashboardRequest",
    "ErrorReportingPanel",
    "IncidentList",
    "ColumnLayout",
    "GridLayout",
    "MosaicLayout",
    "RowLayout",
    "LogsPanel",
    "Threshold",
    "TimeSeriesFilter",
    "TimeSeriesFilterRatio",
    "TimeSeriesQuery",
    "SparkChartType",
    "PieChart",
    "Scorecard",
    "SectionHeader",
    "SingleViewGroup",
    "TimeSeriesTable",
    "TableDisplayOptions",
    "Text",
    "Widget",
    "ChartOptions",
    "XyChart",
)



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.protobuf import duration_pb2 as duration  # type: ignore
import proto  # type: ignore

from google.monitoring.dashboard_v1.types import metrics

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Scorecard",
    },
)


class Scorecard(proto.Message):
    r"""A widget showing the latest value of a metric, and how this
    value relates to one or more thresholds.

    Attributes:
        time_series_query (~.metrics.TimeSeriesQuery):
            Required. Fields for querying time series
            data from the Stackdriver metrics API.
        gauge_view (~.scorecard.Scorecard.GaugeView):
            Will cause the scorecard to show a gauge
            chart.
        spark_chart_view (~.scorecard.Scorecard.SparkChartView):
            Will cause the scorecard to show a spark
            chart.
        thresholds (Sequence[~.metrics.Threshold]):
            The thresholds used to determine the state of
            the scorecard given the time series' current
            value. For an actual value x, the scorecard is
            in a danger state if x is less than or equal to
            a danger threshold that triggers below, or
            greater than or equal to a danger threshold that
            triggers above. Similarly, if x is above/below a
            warning threshold that triggers above/below,
            then the scorecard is in a warning state -
            unless x also puts it in a danger state. (Danger
            trumps warning.)
            As an example, consider a scorecard with the
            following four thresholds: {
              value: 90,
              category: 'DANGER',
              trigger: 'ABOVE',
            },
            {
              value: 70,
              category: 'WARNING',
              trigger: 'ABOVE',
            },
            {
              value: 10,
              category: 'DANGER',
              trigger: 'BELOW',
            },
            {
              value: 20,
              category: 'WARNING',
              trigger: 'BELOW',
            }

            Then: values less than or equal to 10 would put
            the scorecard in a DANGER state, values greater
            than 10 but less than or equal to 20 a WARNING
            state, values strictly between 20 and 70 an OK
            state, values greater than or equal to 70 but
            less than 90 a WARNING state, and values greater
            than or equal to 90 a DANGER state.
    """

    class GaugeView(proto.Message):
        r"""A gauge chart shows where the current value sits within a
        pre-defined range. The upper and lower bounds should define the
        possible range of values for the scorecard's query (inclusive).

        Attributes:
            lower_bound (float):
                The lower bound for this gauge chart. The
                value of the chart should always be greater than
                or equal to this.
            upper_bound (float):
                The upper bound for this gauge chart. The
                value of the chart should always be less than or
                equal to this.
        """

        lower_bound = proto.Field(proto.DOUBLE, number=1)

        upper_bound = proto.Field(proto.DOUBLE, number=2)

    class SparkChartView(proto.Message):
        r"""A sparkChart is a small chart suitable for inclusion in a
        table-cell or inline in text. This message contains the
        configuration for a sparkChart to show up on a Scorecard,
        showing recent trends of the scorecard's timeseries.

        Attributes:
            spark_chart_type (~.metrics.SparkChartType):
                Required. The type of sparkchart to show in
                this chartView.
            min_alignment_period (~.duration.Duration):
                The lower bound on data point frequency in
                the chart implemented by specifying the minimum
                alignment period to use in a time series query.
                For example, if the data is published once every
                10 minutes it would not make sense to fetch and
                align data at one minute intervals. This field
                is optional and exists only as a hint.
        """

        spark_chart_type = proto.Field(
            proto.ENUM,
            number=1,
            enum=metrics.SparkChartType,
        )

        min_alignment_period = proto.Field(
            proto.MESSAGE,
            number=2,
            message=duration.Duration,
        )

    time_series_query = proto.Field(
        proto.MESSAGE,
        number=1,
        message=metrics.TimeSeriesQuery,
    )

    gauge_view = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="data_view",
        message=GaugeView,
    )

    spark_chart_view = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="data_view",
        message=SparkChartView,
    )

    thresholds = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=metrics.Threshold,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.api import monitored_resource_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "IncidentList",
    },
)


class IncidentList(proto.Message):
    r"""A widget that displays a list of incidents

    Attributes:
        monitored_resources (MutableSequence[google.api.monitored_resource_pb2.MonitoredResource]):
            Optional. The monitored resource for which
            incidents are listed. The resource doesn't need
            to be fully specified. That is, you can specify
            the resource type but not the values of the
            resource labels. The resource type and labels
            are used for filtering.
        policy_names (MutableSequence[str]):
            Optional. A list of alert policy names to filter the
            incident list by. Don't include the project ID prefix in the
            policy name. For example, use ``alertPolicies/utilization``.
    """

    monitored_resources: MutableSequence[
        monitored_resource_pb2.MonitoredResource
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=monitored_resource_pb2.MonitoredResource,
    )
    policy_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.protobuf import duration_pb2 as duration  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "Aggregation",
        "PickTimeSeriesFilter",
        "StatisticalTimeSeriesFilter",
    },
)


class Aggregation(proto.Message):
    r"""Describes how to combine multiple time series to provide a different
    view of the data. Aggregation of time series is done in two steps.
    First, each time series in the set is *aligned* to the same time
    interval boundaries, then the set of time series is optionally
    *reduced* in number.

    Alignment consists of applying the ``per_series_aligner`` operation
    to each time series after its data has been divided into regular
    ``alignment_period`` time intervals. This process takes *all* of the
    data points in an alignment period, applies a mathematical
    transformation such as averaging, minimum, maximum, delta, etc., and
    converts them into a single data point per period.

    Reduction is when the aligned and transformed time series can
    optionally be combined, reducing the number of time series through
    similar mathematical transformations. Reduction involves applying a
    ``cross_series_reducer`` to all the time series, optionally sorting
    the time series into subsets with ``group_by_fields``, and applying
    the reducer to each subset.

    The raw time series data can contain a huge amount of information
    from multiple sources. Alignment and reduction transforms this mass
    of data into a more manageable and representative collection of
    data, for example "the 95% latency across the average of all tasks
    in a cluster". This representative data can be more easily graphed
    and comprehended, and the individual time series data is still
    available for later drilldown. For more details, see `Filtering and
    aggregation <https://cloud.google.com/monitoring/api/v3/aggregation>`__.

    Attributes:
        alignment_period (~.duration.Duration):
            The ``alignment_period`` specifies a time interval, in
            seconds, that is used to divide the data in all the [time
            series][google.monitoring.v3.TimeSeries] into consistent
            blocks of time. This will be done before the per-series
            aligner can be applied to the data.

            The value must be at least 60 seconds. If a per-series
            aligner other than ``ALIGN_NONE`` is specified, this field
            is required or an error is returned. If no per-series
            aligner is specified, or the aligner ``ALIGN_NONE`` is
            specified, then this field is ignored.
        per_series_aligner (~.common.Aggregation.Aligner):
            An ``Aligner`` describes how to bring the data points in a
            single time series into temporal alignment. Except for
            ``ALIGN_NONE``, all alignments cause all the data points in
            an ``alignment_period`` to be mathematically grouped
            together, resulting in a single data point for each
            ``alignment_period`` with end timestamp at the end of the
            period.

            Not all alignment operations may be applied to all time
            series. The valid choices depend on the ``metric_kind`` and
            ``value_type`` of the original time series. Alignment can
            change the ``metric_kind`` or the ``value_type`` of the time
            series.

            Time series data must be aligned in order to perform
            cross-time series reduction. If ``cross_series_reducer`` is
            specified, then ``per_series_aligner`` must be specified and
            not equal to ``ALIGN_NONE`` and ``alignment_period`` must be
            specified; otherwise, an error is returned.
        cross_series_reducer (~.common.Aggregation.Reducer):
            The reduction operation to be used to combine time series
            into a single time series, where the value of each data
            point in the resulting series is a function of all the
            already aligned values in the input time series.

            Not all reducer operations can be applied to all time
            series. The valid choices depend on the ``metric_kind`` and
            the ``value_type`` of the original time series. Reduction
            can yield a time series with a different ``metric_kind`` or
            ``value_type`` than the input time series.

            Time series data must first be aligned (see
            ``per_series_aligner``) in order to perform cross-time
            series reduction. If ``cross_series_reducer`` is specified,
            then ``per_series_aligner`` must be specified, and must not
            be ``ALIGN_NONE``. An ``alignment_period`` must also be
            specified; otherwise, an error is returned.
        group_by_fields (Sequence[str]):
            The set of fields to preserve when ``cross_series_reducer``
            is specified. The ``group_by_fields`` determine how the time
            series are partitioned into subsets prior to applying the
            aggregation operation. Each subset contains time series that
            have the same value for each of the grouping fields. Each
            individual time series is a member of exactly one subset.
            The ``cross_series_reducer`` is applied to each subset of
            time series. It is not possible to reduce across different
            resource types, so this field implicitly contains
            ``resource.type``. Fields not specified in
            ``group_by_fields`` are aggregated away. If
            ``group_by_fields`` is not specified and all the time series
            have the same resource type, then the time series are
            aggregated into a single output time series. If
            ``cross_series_reducer`` is not defined, this field is
            ignored.
    """

    class Aligner(proto.Enum):
        r"""The ``Aligner`` specifies the operation that will be applied to the
        data points in each alignment period in a time series. Except for
        ``ALIGN_NONE``, which specifies that no operation be applied, each
        alignment operation replaces the set of data values in each
        alignment period with a single value: the result of applying the
        operation to the data values. An aligned time series has a single
        data value at the end of each ``alignment_period``.

        An alignment operation can change the data type of the values, too.
        For example, if you apply a counting operation to boolean values,
        the data ``value_type`` in the original time series is ``BOOLEAN``,
        but the ``value_type`` in the aligned result is ``INT64``.
        """
        ALIGN_NONE = 0
        ALIGN_DELTA = 1
        ALIGN_RATE = 2
        ALIGN_INTERPOLATE = 3
        ALIGN_NEXT_OLDER = 4
        ALIGN_MIN = 10
        ALIGN_MAX = 11
        ALIGN_MEAN = 12
        ALIGN_COUNT = 13
        ALIGN_SUM = 14
        ALIGN_STDDEV = 15
        ALIGN_COUNT_TRUE = 16
        ALIGN_COUNT_FALSE = 24
        ALIGN_FRACTION_TRUE = 17
        ALIGN_PERCENTILE_99 = 18
        ALIGN_PERCENTILE_95 = 19
        ALIGN_PERCENTILE_50 = 20
        ALIGN_PERCENTILE_05 = 21
        ALIGN_PERCENT_CHANGE = 23

    class Reducer(proto.Enum):
        r"""A Reducer operation describes how to aggregate data points
        from multiple time series into a single time series, where the
        value of each data point in the resulting series is a function
        of all the already aligned values in the input time series.
        """
        REDUCE_NONE = 0
        REDUCE_MEAN = 1
        REDUCE_MIN = 2
        REDUCE_MAX = 3
        REDUCE_SUM = 4
        REDUCE_STDDEV = 5
        REDUCE_COUNT = 6
        REDUCE_COUNT_TRUE = 7
        REDUCE_COUNT_FALSE = 15
        REDUCE_FRACTION_TRUE = 8
        REDUCE_PERCENTILE_99 = 9
        REDUCE_PERCENTILE_95 = 10
        REDUCE_PERCENTILE_50 = 11
        REDUCE_PERCENTILE_05 = 12

    alignment_period = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration.Duration,
    )

    per_series_aligner = proto.Field(
        proto.ENUM,
        number=2,
        enum=Aligner,
    )

    cross_series_reducer = proto.Field(
        proto.ENUM,
        number=4,
        enum=Reducer,
    )

    group_by_fields = proto.RepeatedField(proto.STRING, number=5)


class PickTimeSeriesFilter(proto.Message):
    r"""Describes a ranking-based time series filter. Each input time series
    is ranked with an aligner. The filter will allow up to
    ``num_time_series`` time series to pass through it, selecting them
    based on the relative ranking.

    For example, if ``ranking_method`` is
    ``METHOD_MEAN``,\ ``direction`` is ``BOTTOM``, and
    ``num_time_series`` is 3, then the 3 times series with the lowest
    mean values will pass through the filter.

    Attributes:
        ranking_method (~.common.PickTimeSeriesFilter.Method):
            ``ranking_method`` is applied to each time series
            independently to produce the value which will be used to
            compare the time series to other time series.
        num_time_series (int):
            How many time series to allow to pass through
            the filter.
        direction (~.common.PickTimeSeriesFilter.Direction):
            How to use the ranking to select time series
            that pass through the filter.
    """

    class Method(proto.Enum):
        r"""The value reducers that can be applied to a
        ``PickTimeSeriesFilter``.
        """
        METHOD_UNSPECIFIED = 0
        METHOD_MEAN = 1
        METHOD_MAX = 2
        METHOD_MIN = 3
        METHOD_SUM = 4
        METHOD_LATEST = 5

    class Direction(proto.Enum):
        r"""Describes the ranking directions."""
        DIRECTION_UNSPECIFIED = 0
        TOP = 1
        BOTTOM = 2

    ranking_method = proto.Field(
        proto.ENUM,
        number=1,
        enum=Method,
    )

    num_time_series = proto.Field(proto.INT32, number=2)

    direction = proto.Field(
        proto.ENUM,
        number=3,
        enum=Direction,
    )


class StatisticalTimeSeriesFilter(proto.Message):
    r"""A filter that ranks streams based on their statistical
    relation to other streams in a request.
    Note: This field is deprecated and completely ignored by the
    API.

    Attributes:
        ranking_method (~.common.StatisticalTimeSeriesFilter.Method):
            ``rankingMethod`` is applied to a set of time series, and
            then the produced value for each individual time series is
            used to compare a given time series to others. These are
            methods that cannot be applied stream-by-stream, but rather
            require the full context of a request to evaluate time
            series.
        num_time_series (int):
            How many time series to output.
    """

    class Method(proto.Enum):
        r"""The filter methods that can be applied to a stream."""
        METHOD_UNSPECIFIED = 0
        METHOD_CLUSTER_OUTLIER = 1

    ranking_method = proto.Field(
        proto.ENUM,
        number=1,
        enum=Method,
    )

    num_time_series = proto.Field(proto.INT32, number=2)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import warnings

from google.monitoring.dashboard_v1.services.dashboards_service.async_client import (
    DashboardsServiceAsyncClient,
)
from google.monitoring.dashboard_v1.services.dashboards_service.client import (
    DashboardsServiceClient,
)
from google.monitoring.dashboard_v1.types.common import (
    Aggregation,
    PickTimeSeriesFilter,
    StatisticalTimeSeriesFilter,
)
from google.monitoring.dashboard_v1.types.dashboard import Dashboard
from google.monitoring.dashboard_v1.types.dashboards_service import (
    CreateDashboardRequest,
    DeleteDashboardRequest,
    GetDashboardRequest,
    ListDashboardsRequest,
    ListDashboardsResponse,
    UpdateDashboardRequest,
)
from google.monitoring.dashboard_v1.types.layouts import (
    ColumnLayout,
    GridLayout,
    RowLayout,
)
from google.monitoring.dashboard_v1.types.metrics import (
    SparkChartType,
    Threshold,
    TimeSeriesFilter,
    TimeSeriesFilterRatio,
    TimeSeriesQuery,
)
from google.monitoring.dashboard_v1.types.scorecard import Scorecard
from google.monitoring.dashboard_v1.types.text import Text
from google.monitoring.dashboard_v1.types.widget import Widget
from google.monitoring.dashboard_v1.types.xychart import ChartOptions, XyChart

__all__ = (
    "Aggregation",
    "ChartOptions",
    "ColumnLayout",
    "CreateDashboardRequest",
    "Dashboard",
    "DashboardsServiceAsyncClient",
    "DashboardsServiceClient",
    "DeleteDashboardRequest",
    "GetDashboardRequest",
    "GridLayout",
    "ListDashboardsRequest",
    "ListDashboardsResponse",
    "PickTimeSeriesFilter",
    "RowLayout",
    "Scorecard",
    "SparkChartType",
    "StatisticalTimeSeriesFilter",
    "Text",
    "Threshold",
    "TimeSeriesFilter",
    "TimeSeriesFilterRatio",
    "TimeSeriesQuery",
    "UpdateDashboardRequest",
    "Widget",
    "XyChart",
)

import_warning_message = (
    "The client in the `google.monitoring.dashboard` namespace is no longer updated. "
    "Please use the client in namespace `google.cloud.monitoring_dashboard` instead. "
    "In a future release, importing code from the `google.monitoring.dashboard` namespace "
    "may result in a RuntimeError. If you need to continue to use `google.monitoring.dashboard` "
    "after this date, please pin to a specific version of 'google-cloud-monitoring-dashboards'. "
    "If you have questions, please file an issue: "
    "https://github.com/googleapis/python-monitoring-dashboards/issues."
)

warnings.warn(import_warning_message, ImportWarning)



# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.protobuf import duration_pb2 as duration  # type: ignore
import proto  # type: ignore

from google.monitoring.dashboard_v1.types import metrics

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "XyChart",
        "ChartOptions",
    },
)


class XyChart(proto.Message):
    r"""A chart that displays data on a 2D (X and Y axes) plane.

    Attributes:
        data_sets (Sequence[~.xychart.XyChart.DataSet]):
            Required. The data displayed in this chart.
        timeshift_duration (~.duration.Duration):
            The duration used to display a comparison
            chart. A comparison chart simultaneously shows
            values from two similar-length time periods
            (e.g., week-over-week metrics).
            The duration must be positive, and it can only
            be applied to charts with data sets of LINE plot
            type.
        thresholds (Sequence[~.metrics.Threshold]):
            Threshold lines drawn horizontally across the
            chart.
        x_axis (~.xychart.XyChart.Axis):
            The properties applied to the X axis.
        y_axis (~.xychart.XyChart.Axis):
            The properties applied to the Y axis.
        chart_options (~.xychart.ChartOptions):
            Display options for the chart.
    """

    class DataSet(proto.Message):
        r"""Groups a time series query definition with charting options.

        Attributes:
            time_series_query (~.metrics.TimeSeriesQuery):
                Required. Fields for querying time series
                data from the Stackdriver metrics API.
            plot_type (~.xychart.XyChart.DataSet.PlotType):
                How this data should be plotted on the chart.
            legend_template (str):
                A template string for naming ``TimeSeries`` in the resulting
                data set. This should be a string with interpolations of the
                form ``${label_name}``, which will resolve to the label's
                value.
            min_alignment_period (~.duration.Duration):
                Optional. The lower bound on data point frequency for this
                data set, implemented by specifying the minimum alignment
                period to use in a time series query For example, if the
                data is published once every 10 minutes, the
                ``min_alignment_period`` should be at least 10 minutes. It
                would not make sense to fetch and align data at one minute
                intervals.
        """

        class PlotType(proto.Enum):
            r"""The types of plotting strategies for data sets."""
            PLOT_TYPE_UNSPECIFIED = 0
            LINE = 1
            STACKED_AREA = 2
            STACKED_BAR = 3
            HEATMAP = 4

        time_series_query = proto.Field(
            proto.MESSAGE,
            number=1,
            message=metrics.TimeSeriesQuery,
        )

        plot_type = proto.Field(
            proto.ENUM,
            number=2,
            enum="XyChart.DataSet.PlotType",
        )

        legend_template = proto.Field(proto.STRING, number=3)

        min_alignment_period = proto.Field(
            proto.MESSAGE,
            number=4,
            message=duration.Duration,
        )

    class Axis(proto.Message):
        r"""A chart axis.

        Attributes:
            label (str):
                The label of the axis.
            scale (~.xychart.XyChart.Axis.Scale):
                The axis scale. By default, a linear scale is
                used.
        """

        class Scale(proto.Enum):
            r"""Types of scales used in axes."""
            SCALE_UNSPECIFIED = 0
            LINEAR = 1
            LOG10 = 2

        label = proto.Field(proto.STRING, number=1)

        scale = proto.Field(
            proto.ENUM,
            number=2,
            enum="XyChart.Axis.Scale",
        )

    data_sets = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=DataSet,
    )

    timeshift_duration = proto.Field(
        proto.MESSAGE,
        number=4,
        message=duration.Duration,
    )

    thresholds = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=metrics.Threshold,
    )

    x_axis = proto.Field(
        proto.MESSAGE,
        number=6,
        message=Axis,
    )

    y_axis = proto.Field(
        proto.MESSAGE,
        number=7,
        message=Axis,
    )

    chart_options = proto.Field(
        proto.MESSAGE,
        number=8,
        message="ChartOptions",
    )


class ChartOptions(proto.Message):
    r"""Options to control visual rendering of a chart.

    Attributes:
        mode (~.xychart.ChartOptions.Mode):
            The chart mode.
    """

    class Mode(proto.Enum):
        r"""Chart mode options."""
        MODE_UNSPECIFIED = 0
        COLOR = 1
        X_RAY = 2
        STATS = 3

    mode = proto.Field(
        proto.ENUM,
        number=1,
        enum=Mode,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.monitoring_dashboard_v1.types import common

__protobuf__ = proto.module(
    package="google.monitoring.dashboard.v1",
    manifest={
        "SparkChartType",
        "TimeSeriesQuery",
        "TimeSeriesFilter",
        "TimeSeriesFilterRatio",
        "Threshold",
    },
)


class SparkChartType(proto.Enum):
    r"""Defines the possible types of spark chart supported by the
    ``Scorecard``.

    Values:
        SPARK_CHART_TYPE_UNSPECIFIED (0):
            Not allowed in well-formed requests.
        SPARK_LINE (1):
            The sparkline will be rendered as a small
            line chart.
        SPARK_BAR (2):
            The sparkbar will be rendered as a small bar
            chart.
    """
    SPARK_CHART_TYPE_UNSPECIFIED = 0
    SPARK_LINE = 1
    SPARK_BAR = 2


class TimeSeriesQuery(proto.Message):
    r"""TimeSeriesQuery collects the set of supported methods for
    querying time series data from the Stackdriver metrics API.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        time_series_filter (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilter):
            Filter parameters to fetch time series.

            This field is a member of `oneof`_ ``source``.
        time_series_filter_ratio (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio):
            Parameters to fetch a ratio between two time
            series filters.

            This field is a member of `oneof`_ ``source``.
        time_series_query_language (str):
            A query used to fetch time series with MQL.

            This field is a member of `oneof`_ ``source``.
        prometheus_query (str):
            A query used to fetch time series with
            PromQL.

            This field is a member of `oneof`_ ``source``.
        unit_override (str):
            The unit of data contained in fetched time series. If
            non-empty, this unit will override any unit that accompanies
            fetched data. The format is the same as the
            ```unit`` <https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.metricDescriptors>`__
            field in ``MetricDescriptor``.
        output_full_duration (bool):
            Optional. If set, Cloud Monitoring will treat the full query
            duration as the alignment period so that there will be only
            1 output value.

            \*Note: This could override the configured alignment period
            except for the cases where a series of data points are
            expected, like

            -  XyChart
            -  Scorecard's spark chart
    """

    time_series_filter: "TimeSeriesFilter" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="source",
        message="TimeSeriesFilter",
    )
    time_series_filter_ratio: "TimeSeriesFilterRatio" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message="TimeSeriesFilterRatio",
    )
    time_series_query_language: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="source",
    )
    prometheus_query: str = proto.Field(
        proto.STRING,
        number=6,
        oneof="source",
    )
    unit_override: str = proto.Field(
        proto.STRING,
        number=5,
    )
    output_full_duration: bool = proto.Field(
        proto.BOOL,
        number=7,
    )


class TimeSeriesFilter(proto.Message):
    r"""A filter that defines a subset of time series data that is displayed
    in a widget. Time series data is fetched using the
    ```ListTimeSeries`` <https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list>`__
    method.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        filter (str):
            Required. The `monitoring
            filter <https://cloud.google.com/monitoring/api/v3/filters>`__
            that identifies the metric types, resources, and projects to
            query.
        aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
            By default, the raw time series data is
            returned. Use this field to combine multiple
            time series for different views of the data.
        secondary_aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
            Apply a second aggregation after ``aggregation`` is applied.
        pick_time_series_filter (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter):
            Ranking based time series filter.

            This field is a member of `oneof`_ ``output_filter``.
        statistical_time_series_filter (google.cloud.monitoring_dashboard_v1.types.StatisticalTimeSeriesFilter):
            Statistics based time series filter.
            Note: This field is deprecated and completely
            ignored by the API.

            This field is a member of `oneof`_ ``output_filter``.
    """

    filter: str = proto.Field(
        proto.STRING,
        number=1,
    )
    aggregation: common.Aggregation = proto.Field(
        proto.MESSAGE,
        number=2,
        message=common.Aggregation,
    )
    secondary_aggregation: common.Aggregation = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.Aggregation,
    )
    pick_time_series_filter: common.PickTimeSeriesFilter = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="output_filter",
        message=common.PickTimeSeriesFilter,
    )
    statistical_time_series_filter: common.StatisticalTimeSeriesFilter = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="output_filter",
        message=common.StatisticalTimeSeriesFilter,
    )


class TimeSeriesFilterRatio(proto.Message):
    r"""A pair of time series filters that define a ratio
    computation. The output time series is the pair-wise division of
    each aligned element from the numerator and denominator time
    series.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        numerator (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio.RatioPart):
            The numerator of the ratio.
        denominator (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio.RatioPart):
            The denominator of the ratio.
        secondary_aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
            Apply a second aggregation after the ratio is
            computed.
        pick_time_series_filter (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter):
            Ranking based time series filter.

            This field is a member of `oneof`_ ``output_filter``.
        statistical_time_series_filter (google.cloud.monitoring_dashboard_v1.types.StatisticalTimeSeriesFilter):
            Statistics based time series filter.
            Note: This field is deprecated and completely
            ignored by the API.

            This field is a member of `oneof`_ ``output_filter``.
    """

    class RatioPart(proto.Message):
        r"""Describes a query to build the numerator or denominator of a
        TimeSeriesFilterRatio.

        Attributes:
            filter (str):
                Required. The `monitoring
                filter <https://cloud.google.com/monitoring/api/v3/filters>`__
                that identifies the metric types, resources, and projects to
                query.
            aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
                By default, the raw time series data is
                returned. Use this field to combine multiple
                time series for different views of the data.
        """

        filter: str = proto.Field(
            proto.STRING,
            number=1,
        )
        aggregation: common.Aggregation = proto.Field(
            proto.MESSAGE,
            number=2,
            message=common.Aggregation,
        )

    numerator: RatioPart = proto.Field(
        proto.MESSAGE,
        number=1,
        message=RatioPart,
    )
    denominator: RatioPart = proto.Field(
        proto.MESSAGE,
        number=2,
        message=RatioPart,
    )
    secondary_aggregation: common.Aggregation = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.Aggregation,
    )
    pick_time_series_filter: common.PickTimeSeriesFilter = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="output_filter",
        message=common.PickTimeSeriesFilter,
    )
    statistical_time_series_filter: common.StatisticalTimeSeriesFilter = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="output_filter",
        message=common.StatisticalTimeSeriesFilter,
    )


class Threshold(proto.Message):
    r"""Defines a threshold for categorizing time series values.

    Attributes:
        label (str):
            A label for the threshold.
        value (float):
            The value of the threshold. The value should
            be defined in the native scale of the metric.
        color (google.cloud.monitoring_dashboard_v1.types.Threshold.Color):
            The state color for this threshold. Color is
            not allowed in a XyChart.
        direction (google.cloud.monitoring_dashboard_v1.types.Threshold.Direction):
            The direction for the current threshold.
            Direction is not allowed in a XyChart.
        target_axis (google.cloud.monitoring_dashboard_v1.types.Threshold.TargetAxis):
            The target axis to use for plotting the
            threshold. Target axis is not allowed in a
            Scorecard.
    """

    class Color(proto.Enum):
        r"""The color suggests an interpretation to the viewer when
        actual values cross the threshold. Comments on each color
        provide UX guidance on how users can be expected to interpret a
        given state color.

        Values:
            COLOR_UNSPECIFIED (0):
                Color is unspecified. Not allowed in
                well-formed requests.
            YELLOW (4):
                Crossing the threshold is "concerning"
                behavior.
            RED (6):
                Crossing the threshold is "emergency"
                behavior.
        """
        COLOR_UNSPECIFIED = 0
        YELLOW = 4
        RED = 6

    class Direction(proto.Enum):
        r"""Whether the threshold is considered crossed by an actual
        value above or below its threshold value.

        Values:
            DIRECTION_UNSPECIFIED (0):
                Not allowed in well-formed requests.
            ABOVE (1):
                The threshold will be considered crossed if
                the actual value is above the threshold value.
            BELOW (2):
                The threshold will be considered crossed if
                the actual value is below the threshold value.
        """
        DIRECTION_UNSPECIFIED = 0
        ABOVE = 1
        BELOW = 2

    class TargetAxis(proto.Enum):
        r"""An axis identifier.

        Values:
            TARGET_AXIS_UNSPECIFIED (0):
                The target axis was not specified. Defaults
                to Y1.
            Y1 (1):
                The y_axis (the right axis of chart).
            Y2 (2):
                The y2_axis (the left axis of chart).
        """
        TARGET_AXIS_UNSPECIFIED = 0
        Y1 = 1
        Y2 = 2

    label: str = proto.Field(
        proto.STRING,
        number=1,
    )
    value: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )
    color: Color = proto.Field(
        proto.ENUM,
        number=3,
        enum=Color,
    )
    direction: Direction = proto.Field(
        proto.ENUM,
        number=4,
        enum=Direction,
    )
    target_axis: TargetAxis = proto.Field(
        proto.ENUM,
        number=5,
        enum=TargetAxis,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
